---
name: Bug report
about: Create a bug report to help us improve
title: "[BUG] title of bug"
labels: bug
assignees: ''

---

### Describe the bug
A short 1-2 sentences describing briefly what the bug is.

### Bug Description
#### To Reproduce
- List the steps you took to find the issue (preferably from fresh install, but also just from application startup is fine
#### Expected behavior
- List what the expected behavior is
### Screenshots
Desktop
    OS: *Insert your OS here*

### Additional context
Write additional notes, or things you noticed / might be different about your setup
